Method: OpenID::PAPE::Request#preferred_types

Defined in:
lib/openid/extensions/pape.rb

#preferred_types(supported_types) ⇒ Object

Given a list of authentication policy URIs that a provider supports, this method returns the subset of those types that are preferred by the relying party.



81
82
83
# File 'lib/openid/extensions/pape.rb', line 81

def preferred_types(supported_types)
  @preferred_auth_policies.select{|uri| supported_types.member? uri}
end